IconifyBasilIconSetF class
Class to access the icon data for Basil. All icons are stored as static const strings. This class contains the icons that start with "F".
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- facebookMessengerOutline → const String
-
- facebookMessengerSolid → const String
-
- facebookOutline → const String
-
- facebookSolid → const String
-
- fastForwardOutline → const String
-
- fastForwardSolid → const String
-
- fastRewindOutline → const String
-
- fastRewindSolid → const String
-
- figmaOutline → const String
-
- figmaSolid → const String
-
- fileDownloadOutline → const String
-
- fileDownloadSolid → const String
-
- fileOutline → const String
-
- fileSolid → const String
-
- fileUploadOutline → const String
-
- fileUploadSolid → const String
-
- fileUserOutline → const String
-
- fileUserSolid → const String
-
- filterOutline → const String
-
- filterSolid → const String
-
- fireOutline → const String
-
- fireSolid → const String
-
- flaskAltOutline → const String
-
- flaskAltSolid → const String
-
- flaskOutline → const String
-
- flaskSolid → const String
-
- folderBlockOutline → const String
-
- folderBlockSolid → const String
-
- folderDeleteOutline → const String
-
- folderDeleteSolid → const String
-
- folderLockOutline → const String
-
- folderLockSolid → const String
-
- folderOpenOutline → const String
-
- folderOpenSolid → const String
-
- folderOutline → const String
-
- folderPlusOutline → const String
-
- folderPlusSolid → const String
-
- folderSolid → const String
-
- folderUserOutline → const String
-
- folderUserSolid → const String
-
- forwardOutline → const String
-
- forwardSolid → const String
-